==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/nl/information.php <==
<?php
return [
  '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => 'Module "Push Notifications (Firebase)" en de configuratie van Firebase API Key is vereist',
  '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> status',
  '<strong>Queue</strong> Status' => '<strong>Wachtrij</strong> status',
  'About HumHub' => 'Over',
  'Assets' => 'Assets',
  'Background Jobs' => 'Achtergrond taken',
  'Base URL' => 'Basis-URL',
  'Checking HumHub software prerequisites.' => 'Software vereisten controleren.',
  'Configuration File' => 'Configuratiebestand',
  'Current limit is: {currentLimit}' => 'Huidige limiet is: {currentLimit}',
  'Custom Modules ({modules})' => 'Eigen modules ({modules})',
  'Database' => 'Gegevensbank',
  'Database collation' => 'Gegevensbank-sortering',
  'Database driver - {driver}' => 'Gegevensbankstuurprogramma - {driver}',
  'Database migration results:' => 'Resultaten van de gegevensbank-migratie',
  'Delayed' => 'Uitgesteld',
  'Deprecated Modules ({modules})' => 'Verouderde modules ({modules})',
  'Detected URL: {currentBaseUrl}' => 'Gevonden URL: {currentBaseUrl}',
  'Different table collations in the tables: {tables}' => 'Verschillende tabelcollaties in de tabellen: {tables}',
  'Disabled Functions' => 'Uitgeschakelde functies',
  'Displaying {count} entries per page.' => 'Er worden {count} berichten getoond per pagina.',
  'Done' => 'Klaar',
  'Driver' => 'Stuurprogramma',
  'Dynamic Config' => 'Dynamische configuratie',
  'Error' => 'Fout',
  'Flush entries' => 'Flush berichten',
  'HumHub' => 'HumHub',
  'HumHub Documentation' => 'HumHub documentatie',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub bevindt zich momenteel in de foutopsporingsmodus. Schakel dit uit wanneer u in productie draait!',
  'ICU Data Version ({version})' => 'ICU-gegevensversie ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'ICU-gegevensversie {icuMinVersion} of hoger is vereist',
  'ICU Version ({version})' => 'ICU-versie ({version})',
  'ICU {icuMinVersion} or higher is required' => 'ICU {icuMinVersion} of hoger is vereist',
  'Increase memory limit in {fileName}' => 'Verhoog de geheugenlimiet in {fileName}',
  'Info' => 'Informatie',
  'Install {phpExtension} Extension' => 'Installeer {phpExtension} Extensie',
  'Install {phpExtension} Extension for APC Caching' => 'Installeer de {phpExtension}-extensie voor APC-caching',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installeer de {phpExtension}-extensie voor e-mail S/MIME-ondersteuning.',
  'Last run (daily):' => 'Laatste dagelijkse run:',
  'Last run (hourly):' => 'Laatste run per uur:',
  'Licences' => 'Licenties',
  'Logging' => 'Logging',
  'Make sure that the `proc_open` function is not disabled.' => 'Zorg ervoor dat de functie `proc_open` niet is uitgeschakeld.',
  'Make {filePath} writable for the Webserver/PHP!' => 'Maak {filePath} beschrijfbaar voor de webserver/PHP!',
  'Marketplace API Connection' => 'Marketplace API-verbinding',
  'Memory Limit ({memoryLimit})' => 'Geheugenlimiet ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Minimale versie {minVersion}',
  'Mobile App - Push Service' => 'Mobiele app - Push-service',
  'Module Directory' => 'Modulemap',
  'Multibyte String Functions' => 'Multibyte tekenreeksfuncties',
  'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => 'Moet handmatig worden bijgewerkt. Controleer de compatibiliteit met nieuwere HumHub-versies voordat u gaat updaten.',
  'Never' => 'Nooit',
  'New migrations should be applied: {migrations}' => 'Nieuwe migraties moeten worden toegepast: {migrations}',
  'No pending migrations' => 'Geen migraties in behandeling',
  'Optional' => 'Optioneel',
  'Other' => 'Andere',
  'Outstanding database migrations:' => 'Openstaande gegevensbank migraties:',
  'Permissions' => 'Rechten',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Raadpleeg de documentatie om cronjobs in te stellen en workers in de wachtrij te zetten.',
  'Prerequisites' => 'Vereisten',
  'Pretty URLs' => 'Mooie URL\'s',
  'Profile Image' => 'Profielfoto',
  'Queue successfully cleared.' => 'Wachtrij succesvol gewist.',
  'Re-Run tests' => 'Test opnieuw uitvoeren',
  'Rebuild search index' => 'Zoekindex opnieuw opbouwen',
  'Recommended collation is {collation}' => 'Aanbevolen sortering is {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Aanbevolen sortering is {collation} voor de tabellen: {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Aanbevolen engine is {engine} voor de tabellen: {tables}',
  'Refresh' => 'Vernieuwen',
  'Reserved' => 'Wordt uitgevoerd',
  'Runtime' => 'Runtime',
  'Search index rebuild in progress.' => 'Bezig met  het opnieuw opbouwen van de zoekindex.',
  'Search term...' => 'Zoekterm...',
  'See installation manual for more details.' => 'Bekijk de installatie handleiding voor meer info.',
  'Select category..' => 'Kies een categorie..',
  'Select day' => 'Kies een dag',
  'Select level...' => 'Kies een niveau...',
  'Settings' => 'Instellingen',
  'Supported drivers: {drivers}' => 'Ondersteunde stuurprogramma\'s: {drivers}',
  'Table collations' => 'Tabel sorteringen',
  'Table engines' => 'Tabel-opslagsystemen',
  'The configuration file contains legacy settings. Invalid options: {options}' => 'Het configuratiebestand bevat verouderde instellingen. Ongeldige opties: {options}',
  'The current main HumHub database name is ' => 'De huidige naam van de HumHub-gegevensbank is',
  'The module(s) are no longer maintained and should be uninstalled.' => 'De module(s) worden niet langer onderhouden en moeten worden verwijderd.',
  'There is a new update available! (Latest version: %version%)' => 'Er is een nieuwe update beschikbaar! (Laatste versie: %version%)',
  'This HumHub installation is up to date!' => 'Deze installatie is up-to-date!',
  'Total {count} entries found.' => '{count} berichten gevonden.',
  'Trace' => 'Opsporen',
  'Update Database' => 'Gegevensbank updaten',
  'Uploads' => 'Uploads',
  'Varying table engines are not supported.' => 'Verschillende tabel-opslagsystemen worden niet ondersteund.',
  'Version' => 'Versie',
  'Waiting' => 'Aan het wachten',
  'Warning' => 'Waarschuwing',
  'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => 'Webapplicatie PHP-versie: `{webPhpVersion}`, Cron PHP-versie: `{cronPhpVersion}`',
  'Web Application and Cron uses the same PHP version' => 'Webapplicatie en Cron gebruiken dezelfde PHP-versie',
  'Web Application and Cron uses the same user' => 'Webapplicatie en Cron gebruiken dezelfde gebruiker',
  'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => 'Webtoepassingsgebruiker: `{webUser}`, Cron-gebruiker: `{cronUser}`',
  'Your database is <b>up-to-date</b>.' => 'Uw database is <b>bij de tijd</b>.',
  '{imageExtension} Support' => '{imageExtension} Ondersteuning',
  '{phpExtension} Extension' => '{phpExtension} Extensie',
  '{phpExtension} Support' => '{phpExtension} Ondersteuning',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/nl/information.php <==
<?php
return [
  '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => 'Module "Push Notifications (Firebase)" en de configuratie van Firebase API Key is vereist',
  '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> status',
  '<strong>Queue</strong> Status' => '<strong>Wachtrij</strong> status',
  'About HumHub' => 'Over',
  'Assets' => 'Assets',
  'Background Jobs' => 'Achtergrond taken',
  'Base URL' => 'Basis-URL',
  'Checking HumHub software prerequisites.' => 'Software vereisten controleren.',
  'Configuration File' => 'Configuratiebestand',
  'Current limit is: {currentLimit}' => 'Huidige limiet is: {currentLimit}',
  'Custom Modules ({modules})' => 'Eigen modules ({modules})',
  'Database' => 'Databank',
  'Database collation' => 'Databank-sortering',
  'Database driver - {driver}' => 'Databankstuurprogramma - {driver}',
  'Database migration results:' => 'Resultaten van de databank-migratie',
  'Delayed' => 'Uitgesteld',
  'Deprecated Modules ({modules})' => 'Verouderde modules ({modules})',
  'Detected URL: {currentBaseUrl}' => 'Gevonden URL: {currentBaseUrl}',
  'Different table collations in the tables: {tables}' => 'Verschillende tabelcollaties in de tabellen: {tables}',
  'Disabled Functions' => 'Uitgeschakelde functies',
  'Displaying {count} entries per page.' => 'Er worden {count} berichten getoond per pagina.',
  'Done' => 'Klaar',
  'Driver' => 'Stuurprogramma',
  'Enable <a href="{url}">Link Redirection Service</a>' => '<a href="{url}">Link Redirection Service</a> inschakelen',
  'Error' => 'Fout',
  'Flush entries' => 'Flush berichten',
  'HumHub' => 'HumHub',
  'HumHub Documentation' => 'HumHub documentatie',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub bevindt zich momenteel in de foutopsporingsmodus. Schakel dit uit wanneer u in productie draait!',
  'ICU Data Version ({version})' => 'ICU-gegevensversie ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'ICU-gegevensversie {icuMinVersion} of hoger is vereist',
  'ICU Version ({version})' => 'ICU-versie ({version})',
  'ICU {icuMinVersion} or higher is required' => 'ICU {icuMinVersion} of hoger is vereist',
  'Increase memory limit in {fileName}' => 'Verhoog de geheugenlimiet in {fileName}',
  'Info' => 'Informatie',
  'Install {phpExtension} Extension' => 'Installeer {phpExtension} Extensie',
  'Install {phpExtension} Extension for APC Caching' => 'Installeer de {phpExtension}-extensie voor APC-caching',
  'Install {phpExtension} Extension for Mercure push live driver' => 'Installeer de {phpExtension}-extensie voor de Mercure push live-driver.',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installeer de {phpExtension}-extensie voor e-mail S/MIME-ondersteuning.',
  'Last run (daily):' => 'Laatste dagelijkse run:',
  'Last run (hourly):' => 'Laatste run per uur:',
  'Licences' => 'Licenties',
  'Logging' => 'Logging',
  'Make sure that the `proc_open` function is not disabled.' => 'Zorg ervoor dat de functie `proc_open` niet is uitgeschakeld.',
  'Make {filePath} writable for the Webserver/PHP!' => 'Maak {filePath} beschrijfbaar voor de webserver/PHP!',
  'Marketplace API Connection' => 'Marketplace API-verbinding',
  'Memory Limit ({memoryLimit})' => 'Geheugenlimiet ({memoryLimit})',
  'Minimum Version {minVersion}' => 'Minimale versie {minVersion}',
  'Mobile App - Push Service' => 'Mobiele app - Push-service',
  'Module Directory' => 'Modulemap',
  'Multibyte String Functions' => 'Multibyte tekenreeksfuncties',
  'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => 'Moet handmatig worden bijgewerkt. Controleer de compatibiliteit met nieuwere HumHub-versies voordat u gaat vernieuwen.',
  'Never' => 'Nooit',
  'New migrations should be applied: {migrations}' => 'Nieuwe migraties moeten worden toegepast: {migrations}',
  'No pending migrations' => 'Geen migraties in behandeling',
  'Optional' => 'Optioneel',
  'Other' => 'Andere',
  'Outstanding database migrations:' => 'Openstaande databank migraties:',
  'Permissions' => 'Rechten',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Raadpleeg de documentatie om cronjobs in te stellen en workers in de wachtrij te zetten.',
  'Prerequisites' => 'Vereisten',
  'Pretty URLs' => 'Mooie URL\'s',
  'Profile Image' => 'Profielfoto',
  'Queue successfully cleared.' => 'Wachtrij succesvol gewist.',
  'Re-Run tests' => 'Test opnieuw uitvoeren',
  'Rebuild search index' => 'Zoekindex opnieuw opbouwen',
  'Recommended collation is {collation}' => 'Aanbevolen sortering is {collation}',
  'Recommended collation is {collation} for the tables: {tables}' => 'Aanbevolen sortering is {collation} voor de tabellen: {tables}',
  'Recommended engine is {engine} for the tables: {tables}' => 'Aanbevolen engine is {engine} voor de tabellen: {tables}',
  'Refresh' => 'Vernieuwen',
  'Reserved' => 'Wordt uitgevoerd',
  'Runtime' => 'Runtime',
  'Search index rebuild in progress.' => 'Bezig met  het opnieuw opbouwen van de zoekindex.',
  'Search term...' => 'Zoekterm...',
  'See installation manual for more details.' => 'Bekijk de installatie handleiding voor meer info.',
  'Select category..' => 'Kies een categorie..',
  'Select day' => 'Kies een dag',
  'Select level...' => 'Kies een niveau...',
  'Settings' => 'Instellingen',
  'Supported drivers: {drivers}' => 'Ondersteunde stuurprogramma\'s: {drivers}',
  'Table collations' => 'Tabel sorteringen',
  'Table engines' => 'Tabel-opslagsystemen',
  'The configuration file contains legacy settings. Invalid options: {options}' => 'Het configuratiebestand bevat verouderde instellingen. Ongeldige opties: {options}',
  'The current main HumHub database name is ' => 'De huidige naam van de HumHub-databank is',
  'The module(s) are no longer maintained and should be uninstalled.' => 'De module(s) worden niet langer onderhouden en moeten worden verwijderd.',
  'There is a new update available! (Latest version: %version%)' => 'Er is een nieuwe versie (%version%) beschikbaar!',
  'This HumHub installation is up to date!' => 'Deze installatie is actueel!',
  'Total {count} entries found.' => '{count} berichten gevonden.',
  'Trace' => 'Opsporen',
  'Update Database' => 'Databank vernieuwen',
  'Uploads' => 'Uploads',
  'Uploads - File' => 'Uploads - Bestand',
  'Varying table engines are not supported.' => 'Verschillende tabel-opslagsystemen worden niet ondersteund.',
  'Version' => 'Versie',
  'Waiting' => 'Aan het wachten',
  'Warning' => 'Waarschuwing',
  'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => 'Webapplicatie PHP-versie: `{webPhpVersion}`, Cron PHP-versie: `{cronPhpVersion}`',
  'Web Application and Cron uses the same PHP version' => 'Webapplicatie en Cron gebruiken dezelfde PHP-versie',
  'Web Application and Cron uses the same user' => 'Webapplicatie en Cron gebruiken dezelfde gebruiker',
  'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => 'Webtoepassingsgebruiker: `{webUser}`, Cron-gebruiker: `{cronUser}`',
  'Your database is <b>up-to-date</b>.' => 'Uw database is <b>actueel</b>.',
  '{imageExtension} Support' => '{imageExtension} Ondersteuning',
  '{phpExtension} Extension' => '{phpExtension} Extensie',
  '{phpExtension} Support' => '{phpExtension} Ondersteuning',
];
